urn_nbn_api.api_structures.digital_library module
=================================================

.. automodule:: urn_nbn_api.api_structures.digital_library
    :members:
    :undoc-members:
    :show-inheritance:
